import java.io.*;
import java.math.BigInteger;
import java.util.*;

import static java.lang.Math.min;

public final class Main {
    static FastReader in;
    static FastWriter out;
    static final int INF = 1000 * 1000 * 1000 + 20;

    static void exit() {
        out.close();
        System.exit(0);
    }
	
	static final int MAX_N = 200 * 1000 + 228;

	static int n;
    static ArrayList<Integer>[] children = new ArrayList[MAX_N];
	static int[] weight = new int[MAX_N];
    static int[] subtreeSize = new int[MAX_N];
    static long[] subtreeSum = new long[MAX_N];
    static int[] subtreeMin = new int[MAX_N];
	static long totalCost = 0;


	public static void dfs(int i) {
		if (!children[i].isEmpty()) {
			subtreeSize[i] = 0;
			subtreeSum[i] = 0;
			subtreeMin[i] = weight[i];

			int maxChildSize = 0;
			int maxChildSizeVertex = 0;
			int minSubtreeCost = INF;
			int minSubtreeCost2 = INF;

			for (int u : children[i]) {
			    dfs(u);
				subtreeSize[i] += subtreeSize[u];
				subtreeSum[i] += subtreeSum[u];
				if (subtreeMin[u] < minSubtreeCost2) {
					minSubtreeCost2 = subtreeMin[u];
				}

				if (minSubtreeCost2 < minSubtreeCost) {
					int tmp = minSubtreeCost;
					minSubtreeCost = minSubtreeCost2;
					minSubtreeCost2 = tmp;
				}

				if (maxChildSize < subtreeSize[u]) {
					maxChildSize = subtreeSize[u];
					maxChildSizeVertex = u;
				}
			}

			totalCost += subtreeSum[i];

			if (maxChildSize * 2 > subtreeSize[i]) {
				int d = maxChildSize * 2 - subtreeSize[i];
				totalCost += (long)((minSubtreeCost == subtreeMin[maxChildSizeVertex]) ? minSubtreeCost2 : minSubtreeCost) * d;
			} else if (subtreeSize[i] % 2 == 1) {
				totalCost += minSubtreeCost;
			}

			subtreeMin[i] = min(subtreeMin[i], minSubtreeCost);
			++subtreeSize[i];
			subtreeSum[i] += weight[i];
		} else {
			subtreeSize[i] = 1;
			subtreeSum[i] = weight[i];
			subtreeMin[i] = weight[i];
		}
	}

    public static void main(String[] args) {
        in = new FastReader(new InputStreamReader(System.in));
        out = new FastWriter(new OutputStreamWriter(System.out));
        n = in.nextInt();

        for (int i = 1; i <= n; ++i) {
            children[i] = new ArrayList<>();
        }

        for (int i = 2; i <= n; ++i) {
            int x = in.nextInt();
            children[x].add(i);
        }

        for (int i = 2; i <= n; ++i) {
            weight[i] = in.nextInt();
        }
		
		dfs(1);

        out.println(totalCost);
        exit();
    }
}

class FastReader {
    BufferedReader br;
    StringTokenizer tk;

    FastReader(InputStreamReader ir) {
        br = new BufferedReader(ir);
    }

    String next() {
        while ((tk == null) || (!tk.hasMoreElements())) {
            tk = new StringTokenizer(nextLine());
        }
        return tk.nextToken();
    }

    double nextDouble() {
        return Double.parseDouble(next());
    }

    int nextInt() {
        return Integer.parseInt(next());
    }

    long nextLong() {
        return Long.parseLong(next());
    }

    String nextLine() {
        try {
            return br.readLine();
        } catch (IOException e) {
            e.printStackTrace();
            return null;
        }
    }

}

class FastWriter {
    BufferedWriter out;
    Formatter frm;

    FastWriter(OutputStreamWriter writer) {
        out = new BufferedWriter(writer);
        frm = new Formatter(out);
    }

    //never ever use this
    FastWriter printf(String format, Object... args) {
        frm.format(format, args);
        return this;
    }

    FastWriter print(String str) {
        try {
            out.write(str);
        } catch (IOException e) {
            e.printStackTrace();
        }
        return this;
    }

    FastWriter print(int x) {
        return print(Integer.toString(x));
    }

    FastWriter print(long x) {
        return print(Long.toString(x));
    }

    FastWriter print(double x) {
        return print(Double.toString(x));
    }

    FastWriter print(float x) {
        return print(Float.toString(x));
    }

    FastWriter print(short x) {
        return print(Short.toString(x));
    }

    FastWriter print(char c) {
        try {
            out.write(c);
        } catch (IOException e) {
            e.printStackTrace();
        }
        return this;
    }

    FastWriter print(Object x) {
        return print(x.toString());
    }

    FastWriter println() {
        try {
            out.newLine();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return this;
    }

    FastWriter println(String str) {
        return print(str).println();
    }

    FastWriter println(long x) {
        return print(x).println();
    }

    FastWriter println(int x) {
        return print(x).println();
    }

    FastWriter println(double x) {
        return print(x).println();
    }

    FastWriter println(char x) {
        return print(x).println();
    }

    FastWriter println(float x) {
        return print(x).println();
    }

    FastWriter println(short x) {
        return print(x).println();
    }

    FastWriter println(Object x) {
        return print(x).println();
    }

    public void close() {
        try {
            out.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

}
